@@ -3,15 +3,15 @@
 # replace level with deviance (could add other summaries such as median)
 .catD <- function(col,args,doCollar) {
   pred <- numeric(length(col))
-  if(length(args$scorable)>1) {
+  if(length(args$scorable)>0) {
     col <- .preProcCat(col,args$levRestriction)
-    novel <- !(col %in% args$scorable)
+    unhandledNovel <- !(col %in% args$scorable)
     keys <- col
     if(length(args$scores)>0) {
-      keys[novel] <- args$scorable[[1]]   # just to prevent bad lookups
+      keys[unhandledNovel] <- args$scorable[[1]]   # just to prevent bad lookups
       pred <- as.numeric(args$scores[keys]) 
     }
-    pred[novel] <- args$novelCode 
+    pred[unhandledNovel] <- args$unhandledNovelCode # assume large deviation on unseen levels
   }
   pred
 }
@@ -20,7 +20,7 @@
 # see: http://www.win-vector.com/blog/2012/07/modeling-trick-impact-coding-of-categorical-variables-with-many-levels/
 .mkCatD <- function(origVarName,vcolin,rescol,smFactor,levRestriction,weights) {
   vcol <- .preProcCat(vcolin,levRestriction)
-  extraModelDegrees <- max(0,length(unique(vcolin)))
+  extraModelDegrees <- max(0,length(unique(vcolin))-1)
   num <- tapply(rescol*weights,vcol,sum)
   den <- tapply(weights,vcol,sum)
   scorable <- setdiff(names(den)[den>=2],'zap')
@@ -30,9 +30,9 @@
   condMean <- as.list(num/den)
   resids <- rescol-as.numeric(condMean[vcol])
   scores <- sqrt(tapply(resids*resids*weights,vcol,sum)/pmax(den-1,1))
-  novelCode <- 1.0
+  unhandledNovelCode <- 1.0
   if(length(scorable)>0) {
-    novelCode <- max(scores[scorable])
+    unhandledNovelCode <- max(scores[scorable])
   }
   scores <- as.list(scores)
   scores <- scores[names(scores)!='zap'] # don't let zap code
@@ -42,7 +42,7 @@
                     f=.catD,
                     args=list(scores=scores,
                               scorable=scorable,
-                              novelCode=novelCode,
+                              unhandledNovelCode=unhandledNovelCode,
                               levRestriction=levRestriction),
                     treatmentName='Deviation Fact',
                     treatmentCode='catD',
